==> mongodb-5.0.32.gh.tar.gz: mongo-r5.0.32/jstests/aggregation/sources/graphLookup/socialite.js <==
// Cannot implicitly shard accessed collections because unsupported use of sharded collection
// for target collection of $lookup and $graphLookup.
// @tags: [assumes_unsharded_collection]

// In MongoDB 3.4, $graphLookup was introduced. In this file, we test $graphLookup as applied to the
// Socialite schema example available here: https://github.com/mongodb-labs/socialite

(function() {
"use strict";

var follower = db.followers;
var users = db.users;

follower.drop();
users.drop();

var userDocs = [
    {_id: "djw", fullname: "Darren", country: "Australia"},
    {_id: "bmw", fullname: "Bob", country: "Germany"},
    {_id: "jsr", fullname: "Jared", country: "USA"},
    {_id: "ftr", fullname: "Frank", country: "Canada"}
];

userDocs.forEach(function(userDoc) {
    assert.commandWorked(users.insert(userDoc));
});

var followers = [{_f: "djw", _t: "jsr"}, {_f: "jsr", _t: "bmw"}, {_f: "ftr", _t: "bmw"}];

followers.forEach(function(f) {
    assert.commandWorked(follower.insert(f));
});

// Find the social network of "Darren", that is, people Darren follows, and people who are
// followed by someone Darren follows, etc.

var res = users
                  .aggregate({$match: {fullname: "Darren"}},
                             {
                               $graphLookup: {
                                   from: "followers",
                                   startWith: "$_id",
                                   connectFromField: "_t",
                                   connectToField: "_f",
                                   as: "network"
                               }
                             },
                             {$unwind: "$network"},
                             {$project: {_id: "$network._t"}})
                  .toArray();

// "djw" is followed, directly or indirectly, by "jsr" and "bmw".
assert.eq(res.length, 2);
}());

==> mongodb-6.0.22.gh.tar.gz: mongo-r6.0.22/jstests/aggregation/sources/graphLookup/socialite.js <==
// In MongoDB 3.4, $graphLookup was introduced. In this file, we test $graphLookup as applied to the
// Socialite schema example available here: https://github.com/mongodb-labs/socialite

(function() {
"use strict";

load("jstests/libs/fixture_helpers.js");  // For isSharded.

var follower = db.followers;
var users = db.users;

follower.drop();
users.drop();

var userDocs = [
    {_id: "djw", fullname: "Darren", country: "Australia"},
    {_id: "bmw", fullname: "Bob", country: "Germany"},
    {_id: "jsr", fullname: "Jared", country: "USA"},
    {_id: "ftr", fullname: "Frank", country: "Canada"}
];

userDocs.forEach(function(userDoc) {
    assert.commandWorked(users.insert(userDoc));
});

var followers = [{_f: "djw", _t: "jsr"}, {_f: "jsr", _t: "bmw"}, {_f: "ftr", _t: "bmw"}];

followers.forEach(function(f) {
    assert.commandWorked(follower.insert(f));
});

// Do not run the rest of the tests if the foreign collection is implicitly sharded but the flag to
// allow $lookup/$graphLookup into a sharded collection is disabled.
const getShardedLookupParam = db.adminCommand({getParameter: 1, featureFlagShardedLookup: 1});
const isShardedLookupEnabled = getShardedLookupParam.hasOwnProperty("featureFlagShardedLookup") &&
    getShardedLookupParam.featureFlagShardedLookup.value;
if (FixtureHelpers.isSharded(follower) && !isShardedLookupEnabled) {
    return;
}

// Find the social network of "Darren", that is, people Darren follows, and people who are
// followed by someone Darren follows, etc.

var res = users
                  .aggregate({$match: {fullname: "Darren"}},
                             {
                               $graphLookup: {
                                   from: "followers",
                                   startWith: "$_id",
                                   connectFromField: "_t",
                                   connectToField: "_f",
                                   as: "network"
                               }
                             },
                             {$unwind: "$network"},
                             {$project: {_id: "$network._t"}})
                  .toArray();

// "djw" is followed, directly or indirectly, by "jsr" and "bmw".
assert.eq(res.length, 2);
}());
